@@ -831,7 +831,7 @@ class LowLevelTests final : public Test
          }
    };
 
-BOTAN_REGISTER_TEST("pkcs11-lowlevel", LowLevelTests);
+BOTAN_REGISTER_TEST("pkcs11", "pkcs11-lowlevel", LowLevelTests);
 
 #endif
 #endif
